@@ -1,4 +1,9 @@
 package POE::Component::SmokeBox::Dists;
+{
+  $POE::Component::SmokeBox::Dists::VERSION = '1.08';
+}
+
+#ABSTRACT: Search for CPAN distributions by cpanid or distribution name
 
 use strict;
 use warnings;
@@ -13,10 +18,6 @@ use Sort::Versions;
 use IO::Zlib;
 use POE qw(Wheel::Run);
 
-use vars qw($VERSION);
-
-$VERSION = '1.06';
-
 sub author {
   my $package = shift;
   return $package->_spawn( @_, command => 'author' );
@@ -478,12 +479,19 @@ sub _phalanx {
 }
 
 1;
+
 __END__
 
+=pod
+
 =head1 NAME
 
 POE::Component::SmokeBox::Dists - Search for CPAN distributions by cpanid or distribution name
 
+=head1 VERSION
+
+version 1.08
+
 =head1 SYNOPSIS
 
   use strict;
@@ -496,7 +504,7 @@ POE::Component::SmokeBox::Dists - Search for CPAN distributions by cpanid or dis
 
   POE::Session->create(
     package_states => [
-  	'main' => [qw(_start _results)],
+	    'main' => [qw(_start _results)],
     ],
   );
 
@@ -505,8 +513,8 @@ POE::Component::SmokeBox::Dists - Search for CPAN distributions by cpanid or dis
 
   sub _start {
     POE::Component::SmokeBox::Dists->author(
-  	event => '_results',
-  	search => $search,
+      event => '_results',
+      search => $search,
     );
     return;
   }
@@ -610,20 +618,21 @@ The component uses the C<.smokebox> directory to stash the C<02packages.details.
 This is usually located in the current user's home directory. Setting the environment variable C<PERL5_SMOKEBOX_DIR> will
 effect where the C<.smokebox> directory is located.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<CPAN::DistnameInfo>
 
 L<http://qa.perl.org/phalanx>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
